@@ -3,7 +3,7 @@ from typing import Optional
 from torchyolo.automodel import AutoDetectionModel
 
 
-class YoloPredictor:
+class YoloHub:
     def __init__(
         self,
         model_type: str = "yolov5",
@@ -40,11 +40,11 @@ class YoloPredictor:
         self.model = model
         return model
 
-    def yolo_predictor(self, image, yaml_file=None):
+    def prediction(self, image, yaml_file=None):
         return self.model.predict(image, yaml_file=yaml_file)
 
 
 if __name__ == "__main__":
-    model = YoloPredictor(model_type="yolov8", model_path="yolov8n.pt", device="cpu", image_size=640)
+    model = YoloHub(model_type="yolov8", model_path="yolov8n.pt", device="cpu", image_size=640)
     image = "data/highway.jpg"
-    result = model.yolo_predictor(image)
+    result = model.prediction(image)
